__version__ = "0.2.2"

# -----------------------------
# 导入子模块对象，用户可以访问模块
# -----------------------------
from . import algorithms
from . import diffusion_model
from . import graph
from . import utils

# -----------------------------
# 导入核心类到包顶层，用户可以直接访问
# -----------------------------
from .graph import IMGraph
from .diffusion_model import IndependentCascadeModel, LinearThresholdModel, run_monte_carlo_diffusion

# -----------------------------
# __all__ 包含模块和顶层类
# -----------------------------
__all__ = [
    # 模块
    "algorithms",
    "diffusion_model",
    "graph",
    "utils",
    # 顶层类/函数
    "IMGraph",
    "IndependentCascadeModel",
    "LinearThresholdModel",
    "run_monte_carlo_diffusion"
]
